@@ -3,10 +3,10 @@ use super::super::{
     Stats, StatsVec, ToSlice, Vector, STATS_VEC_CAPACTIY,
 };
 use super::{kahan_sum, kahan_sumb};
-use array_to_complex;
-use multicore_support::*;
+use crate::array_to_complex;
+use crate::multicore_support::*;
 use num_complex::Complex64;
-use numbers::*;
+use crate::numbers::*;
 
 /// Offers the same functionality as the `StatisticsOps` trait but
 /// the statistics are calculated in a more precise (and slower) way.
